Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1813)

Unified Diff: chrome/common/render_messages_internal.h

Issue 4924001: JavaScript to Value bridge. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Fix documentation. Created 10 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/common/notification_type.h ('k') | chrome/renderer/render_view.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/common/render_messages_internal.h
diff --git a/chrome/common/render_messages_internal.h b/chrome/common/render_messages_internal.h
index 41a45b1a59755d8a6679a9651886e70838a51a1c..084f9a5f130c48c33039194d3e77a0f4b8b37b8d 100644
--- a/chrome/common/render_messages_internal.h
+++ b/chrome/common/render_messages_internal.h
@@ -45,6 +45,7 @@
// Substitution map for l10n messages.
typedef std::map<std::string, std::string> SubstitutionMap;
+class Value;
class GPUInfo;
class SerializedScriptValue;
class SkBitmap;
@@ -3029,11 +3030,12 @@ IPC_BEGIN_MESSAGES(ViewHost)
SkBitmap /* thumbnail */)
// Response from ViewMsg_ScriptEvalRequest. The ID is the parameter supplied
// to ViewMsg_ScriptEvalRequest. The result is true if the script evaluated
// to the boolean result true, false otherwise.
IPC_MESSAGE_ROUTED2(ViewHostMsg_ScriptEvalResponse,
int /* id */,
- bool /* result */)
+ ListValue /* result */)
// Updates the content restrictions, i.e. to disable print/copy.
IPC_MESSAGE_ROUTED1(ViewHostMsg_UpdateContentRestrictions,
« no previous file with comments | « chrome/common/notification_type.h ('k') | chrome/renderer/render_view.cc » ('j') | no next file with comments »
@@ -3029,11 +3030,12 @@ IPC_BEGIN_MESSAGES(ViewHost)
SkBitmap /* thumbnail */)
// Response from ViewMsg_ScriptEvalRequest. The ID is the parameter supplied
- // to ViewMsg_ScriptEvalRequest. The result is true if the script evaluated
- // to the boolean result true, false otherwise.
+ // to ViewMsg_ScriptEvalRequest. The result has the value returned by the
+ // script as it's only element, one of Null, Boolean, Integer, Real, Date, or
+ // String.
IPC_MESSAGE_ROUTED2(ViewHostMsg_ScriptEvalResponse,
int /* id */,

Powered by Google App Engine
This is Rietveld 408576698